@@ -25,8 +25,8 @@ class Connector(APIResource):
     s3_client = None
 
     @classmethod
-    def get_credentials(cls, user_token: str = None):
-        if cls.credentials is None:
+    def get_credentials(cls, user_token: str = None, renew: bool = False):
+        if (cls.credentials is None) or renew:
             url = '/'.join([cls._CLASS_PREFIX, 'whatify_connect_permissions'])
             requester = APIRequestor()
             if user_token is None:
@@ -53,7 +53,7 @@ class Connector(APIResource):
         os.environ['AWS_DEFAULT_REGION'] = cls.credentials['region']
         fs = s3fs.S3FileSystem()
         try:
-            file_list = fs.ls(cls.get_s3_path(user_token=user_token))
+            file_list = fs.ls(cls.get_s3_path(user_token=user_token), refresh=True)
         except PermissionError as ex:
             print(' '.join(['folder is empty:', str(ex)]))
         return file_list
@@ -76,10 +76,10 @@ class Connector(APIResource):
 
     @classmethod
     def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None, **kwargs):
-        s3_client = cls.get_s3_boto_client(user_token=user_token)
+        cls.get_s3_boto_client(user_token=user_token)
         csv_buffer = StringIO()
         df.to_csv(csv_buffer, **kwargs)
-        s3_client.upload_fileobj(csv_buffer, Bucket=cls.credentials['bucket'], Key='/'.join([cls.credentials['path'], file_name]))
+        cls.s3_client.upload_fileobj(csv_buffer, cls.credentials['bucket'], '/'.join([cls.credentials['path'], file_name]))
 
 
 
